//////////////////////////////////////////////////////////////////////////
// Copyright 2002-2006 Aspose Pty Ltd. All Rights Reserved.
//
// This file is part of Aspose.Words. The source code in this file
// is only intended as a supplement to the documentation, and is provided
// "as is", without warranty of any kind, either expressed or implied.
//////////////////////////////////////////////////////////////////////////

package com.aspose.words.demos;

import com.aspose.words.Document;

import java.sql.ResultSet;

/**
 * Populates a table in a document with information from the database,
 * also inserts images stored in a BLOB field into the document.
 */
public class EmployeesReportDemo extends Demo
{
	public EmployeesReportDemo()
	{
		init("EmployeesReportDemo");
	}

	public Document execute() throws Exception
	{
		//Open the template document
		Document doc = new Document(getPathToTemplateDoc());//JAVA-changed

		//*** Mail Merge Regions
		//
		//Using mail merge regions allows you to repeat a portion of the document for each
		//record in your data source. The most common use for a mail merge region is to grow
		//a table inside a document.
		//
		//Note that mail merge region is a new concept introduced in Aspose.Words and not
		//available in the classic MS Word mail merge.
		//
		//To create a mail merge region inside a document, you need to insert two merge fields
		//with special names TableStart:[TableName] and TableEnd:[TableName] that designate
		//the beginning and end of the mail merge region. Aspose.Words mail merge engine repeats
		//the document content enclosed inside the region for every record in your data source.
		//
		//In this demo, the document contains a table which consists of only two rows:
		//one header and one data row. TableStart:Employees and TableEnd:Employees merge fields
		//that designate the merge region are inserted into the table row along with other merge fields.

		//*** Inserting Images During Mail Merge
		//
		//To instruct Aspose.Words that a particular field in your data source contains an image
		//in binary format, insert a merge field with a special name Image:[FieldName] into your document.
		//The image can be stored in any format recognized by .NET Image.FromFile method.//@todo 1 sk java-specific comment here
		//
		//In this example, the Employees table has the PhotoBLOB field that contains image bytes
		//and Image:PhotoBLOB merge field is used to insert the images into the document.

		ResultSet employees = super.executeQuery("SELECT * FROM Employees");
		//Note the table has to have its TableName set up to match the name of the mail merge region
		//specified in the document in TableStart:[TableName] and TableEnd:[TableName] marks.
		
		//Note it is important to call ExecuteWithRegions, not Execute.
		doc.getMailMerge().executeWithRegions(employees);

		return doc;
	}
}
