//////////////////////////////////////////////////////////////////////////
// Copyright 2002-2006 Aspose Pty Ltd. All Rights Reserved.
//
// This file is part of Aspose.Words. The source code in this file
// is only intended as a supplement to the documentation, and is provided
// "as is", without warranty of any kind, either expressed or implied.
//////////////////////////////////////////////////////////////////////////
package com.aspose.words.documentexplorer;

import javax.swing.*;
import java.io.File;
import java.text.MessageFormat;
/// <summary>
/// Provides static methods for actions that involve dialogs.
/// </summary>
public class Dialogs
{
	/// <summary>
	/// Stores the last accessed file path, so that the next file dialog session should start from there.
	/// </summary>
	private static String mDocumentPath = "";
	/// <summary>
	/// Stores the name of the currently loaded dopcument. Name is stored without extension to be used when saving in different file format.
	/// </summary>
	private static String mDocumentName;

	private static JFileChooser mOpenDialog;
	private static JFileChooser mSaveDialog;

    /// <summary>
    /// This class is purely static.
    /// </summary>
    private Dialogs() {}

	//static ctor, inits open and save dialogs
	static
	{
		mOpenDialog = new JFileChooser();
			mOpenDialog.setAcceptAllFileFilterUsed(false);
			mOpenDialog.setFileFilter(Globals.OPEN_FILE_FILTER);
			mOpenDialog.setMultiSelectionEnabled(false);
			mOpenDialog.setFileSelectionMode(JFileChooser.FILES_ONLY);
			mOpenDialog.setDialogTitle(Globals.OPEN_DOCUMENT_DIALOG_TITLE);

		mSaveDialog = new JFileChooser();
			mSaveDialog.setMultiSelectionEnabled(false);
			mSaveDialog.setFileSelectionMode(JFileChooser.FILES_ONLY);
			mSaveDialog.setDialogTitle(Globals.SAVE_DOCUMENT_DIALOG_TITLE);
			mSaveDialog.setAcceptAllFileFilterUsed(false);
            mSaveDialog.setFileFilter(Globals.SAVE_FILE_FILTER_PDF);
            mSaveDialog.setFileFilter(Globals.SAVE_FILE_FILTER_HTML);
            mSaveDialog.setFileFilter(Globals.SAVE_FILE_FILTER_DOC);
            //corrects filechooser "save as" dialog behaviour like in ms word
			mSaveDialog.addPropertyChangeListener(new SaveDialogChangeListener(mSaveDialog));
	}

	/// <summary>
    /// Selects file name for document to open.
    /// </summary>
    /// <returns>File name of the document selected to be opened.</returns>
    public static String openDocument()
    {
		mOpenDialog.setCurrentDirectory(new File(mDocumentPath));

		if (mOpenDialog.showOpenDialog(Globals.mMainForm)==JFileChooser.APPROVE_OPTION)
        {
            File file = mOpenDialog.getSelectedFile();
            String fileName = file.getAbsolutePath();
			if (file.exists())
			{
				mDocumentPath = file.getParent();
				mDocumentName = file.getName();
				return fileName;
			}
			else
			{
				JOptionPane.showMessageDialog(Globals.mMainForm,
					  MessageFormat.format("File \"{0}\" doesn't exist.", fileName),
					  Globals.APPLICATION_TITLE, JOptionPane.ERROR_MESSAGE);
				return "";
			}
		}
        else
        {
            return "";
        }
    }

    /// <summary>
    /// Selects file name for saving currently opened document.
    /// </summary>
    /// <returns>File name to save the currently opened document with.</returns>
    public static String saveDocument()
    {
		mSaveDialog.setCurrentDirectory(new File(mDocumentPath));
		mSaveDialog.setSelectedFile(new File(mDocumentName));

        if (mSaveDialog.showSaveDialog(Globals.mMainForm)==JFileChooser.APPROVE_OPTION)
        {
            File file = mSaveDialog.getSelectedFile();
			String name = file.getName();

			//file without extension or with non-registered extension
			if (!name.endsWith(".doc") && !name.endsWith(".pdf"))
			{
				String curExtension = ((SaveFileFilter) mSaveDialog.getFileFilter()).mExtension;
				file = Utils.setExtension(file, curExtension);
			}

			if (file.exists())
            {
                String fileName = file.getAbsolutePath();
                if(JOptionPane.showConfirmDialog(Globals.mMainForm,
                        java.text.MessageFormat.format("File \"{0}\" already exists. Would you like to overwrite it ?", fileName),
                        Globals.APPLICATION_TITLE, JOptionPane.YES_NO_OPTION)==JOptionPane.NO_OPTION)
                    return "";
            }

			mDocumentPath = file.getParent();
            return file.getAbsolutePath();
        }
        else
        {
            return "";
        }
    }

}